#
# spec file for package qtox
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define realname qTox

Name:           qtox
Version:        1.17.6
Release:        2.4
Summary:        Tox client
License:        GPL-3.0-only
Group:          Productivity/Networking/Instant Messenger
URL:            https://qtox.github.io/
Source0:        https://github.com/qTox/qTox/releases/download/v%{version}/v%{version}.tar.gz
Source1:        https://github.com/qTox/qTox/releases/download/v%{version}/v%{version}.tar.gz.asc
Source2:        qtox.keyring
BuildRequires:  cmake >= 2.8.11
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Sonnet) >= 5.45
BuildRequires:  cmake(LibsnoreQt5) >= 0.7.0

# needed?
####BuildRequires:  gcc-c++
####BuildRequires:  opencv-devel >= 2.4.9
###BuildRequires:  opencv-qt5-devel
###BuildRequires:  pkgconfig(Qt5Sql5-sqlite)
BuildRequires:  libqt5-qtbase-common-devel >= 5.5.0
BuildRequires:  pkgconfig(sqlite3)
# needed?

%if 0%{?suse_version} > 1500
BuildRequires:  ffmpeg-devel >= 4.0.0
%else
BuildRequires:  ffmpeg-devel
%endif
#BuildRequires:  pkgconfig(libavformat)
#BuildRequires:  pkgconfig(libavdevice)
#BuildRequires:  pkgconfig(libavutil)
#BuildRequires:  pkgconfig(libavcodec)
#BuildRequires:  pkgconfig(libswscale)

BuildRequires:  glib2-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-linguist-devel
BuildRequires:  libqt5-qtbase-devel >= 5.5.0
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core) >= 5.5.0
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(filteraudio)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libqrencode) >= 3.0.3
BuildRequires:  pkgconfig(libsodium)
BuildRequires:  pkgconfig(openal) >= 1.16.0
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(sqlcipher) >= 3.2.0
BuildRequires:  pkgconfig(toxcore) >= 0.2.13
BuildRequires:  pkgconfig(vpx)
BuildRequires:  pkgconfig(xscrnsaver) >= 1.2

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Powerful Tox client that tries to follow the Tox UI mockup while running on all
major systems.

%prep
%setup -q -n qTox

%build
CFLAGS="%{optflags} -Wno-error=parentheses"
mkdir build
pushd build
cmake -DCMAKE_C_FLAGS="$CFLAGS" -DCMAKE_INSTALL_PREFIX=%{_prefix} -DUPDATE_CHECK=False -DDESKTOP_NOTIFICATIONS=True ..
make %{?_smp_mflags} PREFIX=%{_prefix}
popd

%install
make install -C build PREFIX=%{_prefix} DESTDIR=%{buildroot}
# remove non-standard dimensions
rm -rf %{buildroot}%{_datadir}/icons/hicolor/14x14
# decompress svgz to svg
cd %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/
gzip -d < %{name}.svgz > %{name}.svg
rm %{name}.svgz
# fix desktop-file-name
mv %{buildroot}%{_datadir}/applications/io.github.qtox.qTox.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop

%fdupes %{buildroot}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%license LICENSE
%doc README.md CHANGELOG.md
%{_bindir}/%{name}
%{_datadir}/metainfo
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%changelog
* Fri Aug 11 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Drop build time to fix reproducible builds (boo#1047218)
* Sun Jun 26 2022 ecsos <ecsos@opensuse.org>
- Update to 1.17.6
  * Bug Fixes
  - Windows: Correct Program Files directory for 32-bit Windows (47406e74)
  - macos: update deprecated AVFoundation API (484ea7ce)
- Changes from 1.17.5
  * Bug Fixes
  - Update video API usage for newer libavcodec (f5fabc2f)
    + Windows:
  - Restrict non-default install directory permissions (553bd47e)
  - Build NSIS installer in Unicode mode (9f84184b)
  - Define installer language before trying to access it (1353fc93)
  * Features
  - Settings: Add setting for hiding group join and leave system messages (916e797c)
  - UI: Add UI For controlling group join and leave system messages setting (423049db)
  - chatlog: Disable join and leave system messages based on setting (ee0334ac)
* Mon Feb 14 2022 ecsos <ecsos@opensuse.org>
- Update to 1.17.4
  This release only updates dependency versions including
  toktok/c-toxcore to v0.2.13 to address CVE-2021-44847.
  No code changes.
* Fri Dec 10 2021 Giacomo Comes <gcomes.obs@gmail.com>
- Enable desktop notifications.
* Sun Nov 29 2020 ecsos <ecsos@opensuse.org>
- Disable Update_Check to fix coredump.
* Sat Nov 28 2020 Andrey Karepin <egdfree@opensuse.org>
- Update to 1.17.3
  * Features
  - osx: Add support for macOS 10.16, remove support for macOS 10.13 (238b2478)
  - windows:
  - Build our own gdb (3092107a)
  - Make sure no dlls are missing (3e6bc9b1)
  - Link all Windows deps dynamically (5219ebc1)
  * Bug Fixes
  - build: cache debug deps during 2nd stage (2712bc68)
  - osx:
  - Allow rebuild using build script (b5538c3f)
  - Fix missing variables in macOS build script (f741ac99)
  - Update deprecated QDateTime and QProcess APIs (08abedb6)
  - don't tap kde-mac/kde since it us deprecated and unused (b42ac760)
  - tools:
  - Add Windows to toxcore version update script (3ff53e8f)
  - Use correct hash when automatically updating flatpak version (9fb96b08)
  - use a subdirectory for release source archives (533f25e2)
  - travis: Install virtualenv for nightly build upload script (bd5bdf18)
  - windows: iconengines not being installed (399c0231)
* Sun May 10 2020 ecsos <ecsos@opensuse.org>
- Update to 1.17.2
  - This is a release to fix our automatic deployment scripts,
    no code changes.
- Changes from 1.17.1
  * Bug Fixes
  - ci: remove jenkins deploy step (48c688bf)
- Changes from 1.17.0
  The most notable user facing changes are group chats that stay
  intact after disconnects or client shutdown as well as the very
  often requested dark theme. Advanced history search was added,
  as well as file transfers staying in chat history after client
  restart. There are of course also tons of fixes, namely much
  increased stability of audio and video calls as well as audio
  group calls.
  Full changelog see:
  https://github.com/qTox/qTox/blob/master/CHANGELOG.md#v1170-2020-04-19
* Sun Jul 29 2018 ecsos@opensuse.org
- update to 1.16.3
  This point release fixes flatpak build. No feature changes.
- changes from 1.16.2
  This point release fixes dialog spam from receiving invalid
  filenames and logs spam. No feature changes.
  * Bug Fixes
  * *logging:**
  - only log toxcore messages above TRACE level
  * *ui:**
  - don't emit filename change windows for every chat
* Fri Jul  6 2018 ecsos@opensuse.org
- update to 1.16.1
  This point release fixes our deployment of Flapak and AppImage
  on Github. No feature changes.
  * Features
  - deploy: upload Flatpak bundle to Github releases (59b5578c)
  * Bug Fixes
  - deploy: fix file path in AppImage deployment (64602f38)
- changes from 1.16.0
  The most notable additions in this release are a new fullscreen
  mode for video calls, a new call end sound and support for more
  camera resolutions. To distribute qTox in a more user friendly
  manner we now publish Flatpak and AppImage packages.
  * Bug Fixes
  - remove full screen btn from audio group chat (0d3f061b)
  - local toxcore install with bootstrap.sh (9ca38750,
    closes #5199)
  - simple_make.sh script (ead2152d)
  - Fix PR #5182. Eliminating the 'new' operator at
    ToxOptionsWrapper (9b6cd1c0)
  - Fix usage of unitialized functions (06ae7ead)
  - two crashes, uncovered by the persistent groupchat patch
    (48179b6a)
  - delete double initialization callDuration (dc1f5ea0)
  - Core: fix use after free of proxyAddrData (26b59d31)
  - appimage: build sqlcipher form source (64a7c24b)
  - audio:
  - fix error introduced in
    67f2605971cf43093c72f811e4df90ab70544dd6 (40d30153)
  - connect the correct audio callbacks (a00af087)
  - close the audio device after playing a sound (a3370173)
  - build:
  - Elimination the build warnings (Wunused-variable, Wreorder)
    (2cd65610)
  - correct install script nsis for win64 (25e69572)
  - make qTox compile with ffmpeg 4.0 and newer (44193176)
  - chatform:
  - name in window title and close detached chats (39968a31)
  - check for empty path when exporting profile (757791ee,
    closes #5146)
  - core: Clean illegal chars from filenames (ab85716f)
  - docs: update toxcore build instructions (b00cbc1d)
  - file: don't clean the filenames of avatar transfer (2a8ab03e)
  - history: don't save both action prefix and displayed name
    (dfd2de83)
  - leak: Fix few memory leaks (daaa5518)
  - login: start login screen on profile select by -p option
    (1af3ad69)
  - settings:
  - automatically disable UDP when a proxy is set (977b7fc9)
  - prevent segfault on wrong proxy settings (dfd5232e)
  - simple_make: correct variable initialization (1537f83e)
  - theme: clear stylesheet cache on theme colour change
    (8ba8ce91)
  - ui: increase number of low res camera options (72931514)
  - video: unsubscribe the video device correctly (e55f86c6)
  - wayland: Fix desktop file name in Qt properties (c1caeb58)
  * Features
  - Add ability to remove dialog from content dialog with middle
    click (aae567ed)
  - Add ability to quit group with middle click (228c431c)
  - Add middle mouse clicked signal for GenericChatroom
    (65fc1dc2)
  - appimage: build appimage on TravisCI (f7345e4d)
  - call: add call end sound (65896e45)
  - chat:
  - add UI option to mute group peers (2fae2a30)
  - full screen video chat (d6df8883)
  - core: put c-toxcore log messages in the qTox log (4faab075)
  - history: load set number of messages from history (ca32e77d)
* Wed Jun 20 2018 ecsos@opensuse.org
- cleanup spec
* Wed May 16 2018 ecsos@opensuse.org
- update to 1.15.0
  * Performance
  - ui: cache stylesheets to reduce memory usage (6d9d26db)
  * Bug Fixes
  - remove build date and time from main.cpp (23f6ad70)
  - don't use invalid reference after erasing element (1afed5f7)
  - IPC: Update profileName to update IPC ID after login screen
    (d2ad2107)
  - audio:
  - apply gain to both audio channels (f6622e40)
  - move audio timers to and start from audioThread (5d0f9509)
  - avform: Audio/Video settings tab #5011 issue bugfix
    (ad6ddfc4)
  - build: Remove unused vars, add default case for switch
    (bc18990f)
  - chatform: include pressed key(s) when changing focus
    (a8fc6e5c)
  - chattextedit: ChatTextEdit bug fix for issue #5020 Corrected
    (ebdc675c)
  - core: split messages on utf8 multibyte character boundary
    properly (869036f3)
  - docs:
  - include master key fingerprint instead of subkey
    fingerprint (3748ca6b)
  - update dependencies for Debian (7627d60a)
  - history: don't save own messages when history is disabled
    (b852809d)
  - import: don't use java-style iterator before first element
    (acea7c31)
  - login: Don't dereference null pointer (703876c3)
  - name: Clear alias on name change so that name changes are
    visible (c2410e0a)
  - offlinemsg: make faux offline messages purely event based
    (4951f909)
  - profile: don't error if no new avatar is selected (cfdc1cdb)
  - settings:
  - connect enable LAN discovery checkbox (55d8922d)
  - add missing enableTestSound to settings (65d59ba6)
  - ui: remove placeholder update UI (cb0f2635)
  - widget: Fix double free crash on group leave (81989406)
  * Features
  - Weblate: create script to automatically merge Weblate changes
    (96ae4284)
  - camera: add higher resolution camera options (04ecfe3f)
  - ui:
  - add setting for disabling new message notification popup
    (fcd88d65)
  - Add ability to disable LAN discovery (9f8b0fed)
* Wed Apr 18 2018 ecsos@opensuse.org
- update to 1.14.1
  - Fix crashes, name change notification, profile selection,
    and openSUSE package compilation
* Tue Mar 20 2018 ecsos@opensuse.org
- update to 1.14.0
  * Bug Fixes
  - Not quit on close if this setting is enabled (e73dc10c)
  - add search symbol ' in history (3e05279c)
  - Use real channels number (e74cc37a)
  - Allocate memory to input buffer (900f2a1a)
  - Call doAudio on timer timeout (2353a66f)
  - [un]subscribe output in avform (8c05399e)
  - Correct display the call confirm window (CallConfirmWidget)
    (f4fe343e)
  - elimination of warning '-Wreorder' (0869d3d8)
  - Use epsilon to compare float (91dabf11)
  - UI: prevent deadlocks on logout and profile delete (a49e3458)
  - build:
  - move Appdata file installation to /usr/share/metainfo
    (5db0bdd3)
  - add needed ffmpeg decoder to configuration (8973a521)
  - Add missing dependency for openSUSE (f7e089f7)
  - chatform: Broaden URL matching to include unicode (e564b85e)
  - chatlog:
  - Match multi-character emoticons again (9643e48e)
  - parse multi-length emoji properly (5df63f9c)
  - chatwidget: fix send file button not working (af1aebfd)
  - cmake:
  - fix platform extensions for windows (7ad68e2f)
  - add missing dependency (423f0956)
  - core:
  - Adapt qtox to new conferences state change callback.
    (1111949f)
  - Use new callback API for bitrate set (d2deec7c)
  - Use new API for bitrate set (2c8f03da)
  - cpu: Reduce CPU usage by avatar render (8db61f96)
  - friendwidget: Use queued connection to avoid removing 'this'
    (9b4972e0)
  - group: Show correct count of user on first creation
    (0a590336)
  - install: Fix gzip invalid usage (266f63f6)
  - l10n:
  - Correction of the translation into Russian (3fb42b75)
  - Correction of the translation into Russian (9229fdd1)
  - smiley: change license of classic smileys to CC BY-SA 4.0
    (da7c12e2)
  - travis:
  - try working around Travis + gitstats issue (4c980945)
  - switch back to older Ubuntu Image (378daeaa)
  - video:
  - improve debug message (ff2fc18b)
  - choose first available resolution in preview automatically
    (81522dea)
  - use float framerates also for V4L2 (a2927de2)
  - allow not integer framerates (db7ee65d)
  - Fix square form of a video (8de8c14a)
    widget: Fix status pic alignment (d9118cfc)
    windows: %%APPDATA -> %%APPDATA%% in template (f53b8282)
  * Features
  - Add the cmake option USE_CCACHE (aa9cff31)
  - update to the new c-toxcore 0.2.0 conferences api (d3d81bbd)
  - add hot keys for search (ffb51e8a)
  - optimise search in history (18fa8a74)
  - add search in text in group chats (7718734c)
  - remove search button and add line in context menu (8bb80c77)
  - edit load history for search (de9c9061)
  - add text search (b881d32d)
  - add form for search (863c46c7)
  - add a button to search (47d9da98)
  - Prefere new line as message break (3b52402f)
  - UI: new status icons for message notifications (4288785d)
  - avatar: Add outline hightlight on mouse hover (bb26485d)
  - groupchat: mark blocked users with different color (a729f2f8)
  - l10n:
  - add Macedonian translation (1a06f85d)
  - add Macedonian translation using Weblate (41420331)
  - update French translation from Weblate (a7e90969)
  - update Portuguese translation from Weblate (3bad087b)
  - update Portuguese translation from Weblate (8c3be522)
  * Performance
  - widget: don't save on setExpanded if categorywidget is
    unchanged Fix #4932 (b9845e1d)
* Thu Dec  7 2017 ecsos@opensuse.org
- update to 1.13.0
  See https://github.com/qTox/qTox/blob/v1.13.0/CHANGELOG.md
* Sun Nov 12 2017 ecsos@opensuse.org
- update to 1.12.1
  See https://github.com/qTox/qTox/blob/v1.12.1/CHANGELOG.md
* Sat Jul 29 2017 ecsos@opensuse.org
- update to 1.11.0
  See https://github.com/qTox/qTox/blob/v1.11.0/CHANGELOG.md
* Sun Jun 11 2017 ecsos@opensuse.org
- update to 1.10.2
  See https://github.com/qTox/qTox/blob/v1.10.2/CHANGELOG.md
* Tue May 16 2017 ecsos@opensuse.org
- update to 1.10.1
  See https://github.com/qTox/qTox/blob/v1.10.1/CHANGELOG.md
- update to 1.10.0
  See https://github.com/qTox/qTox/blob/v1.10.0/CHANGELOG.md
* Sun Mar 26 2017 ecsos@opensuse.org
- update to 1.9.0
  See https://github.com/qTox/qTox/blob/v1.9.0/CHANGELOG.md
* Sun Feb 12 2017 ecsos@opensuse.org
- update to 1.8.1
  See https://github.com/qTox/qTox/blob/v1.8.1/CHANGELOG.md
- update to 1.8.0
  See https://github.com/qTox/qTox/blob/v1.8.0/CHANGELOG.md
* Fri Jan 13 2017 ecsos@opensuse.org
- update to 1.7.1
  - Contains fixes for FreeBSD.
- update to 1.7.0
  See https://github.com/qTox/qTox/blob/v1.7.0/CHANGELOG.md
- update to 1.6.0
  See https://github.com/qTox/qTox/blob/v1.6.0/CHANGELOG.md
* Sun Aug 21 2016 ecsos@opensuse.org
- update to 1.5.0
  See https://github.com/qTox/qTox/blob/v1.5.0/CHANGELOG.md
* Fri May 13 2016 ecsos@opensuse.org
- update to 1.4.1
  Bug Fixes
  - settings: Look for portable setting in module path, not CWD
    (95634f1c)
  - updater: Use module path, not working dir (0f1c8a78)
* Fri May  6 2016 ecsos@opensuse.org
- update to 1.4.0
  Breaking Changes
  - disable building with filter_audio by default (116cc936)
  Bug Fixes
  - close groupcall if alone (98d51399)
  - disable netcamview if no peer left (622b543d)
  - audiocall button disabled in groupchats (db4f02a0)
  - Close logfile only after the disabling logging to file (de487890)
  - Make logMessageHandler thread-safe (a7ffc08c)
  - Deadlock while rotating logs (c1e2a3c5)
  - increase faux offline message timeout (76d8e193)
  - remove unnecessary qDebug call (66f96019)
  - Widget::updateIcons:
  - workaround QIcon fallback bug (0b53c4fd)
  - fix the way systray icons are loaded (90874a47)
  - addfriendform: Removed extra connect return press (66bcfdae)
  - addfriendform, widget: Remove Accepted Request (53071e95)
  - chatform: regression in detecting tox: type IDs (48f3fb7d)
  - core, widget: Added checks (f28c3a16)
  - file transfer widget: QPushButton allows image to overflow (32d588a4, closes #3042)
  - genericchatitemwidget, micfeedbackwidget: Added members init in the constructor (27faec91)
  - groupaudio:
  - don't set button to green while call running (6d355154)
  - don't play audio while call is inactive (5339ad97)
  - avoid deadlock when ending groupcall (afcd146a)
  - groupinviteform:
  - make list of groups scrollable (b74ecd92)
  - translation invite message (24efaf05)
  - remove deleted buttons from set (f137ba71)
  - l18n: make typing notification & groupchat name translatable (43e61041)
  - login screen: Change text on login tooltip (4e065f13)
  - main: Added check sodium_init result (64a19d34)
  - profile: Don't require .ini to load profile (56a36e2e)
  - profileform:
  - Add toxme username limitation (132f87c0)
  - Deleted extra check and extra url (1f7e23d0)
  - Fixed very quick relogin segfault (88de3a0a)
  - Fixed segfault on logut (2e9295f4)
  - Fix tab order, fix loop (65ab1f4e)
  - screenshot: incorrect screenshot capture resolution under HiDPI (a36248b5)
  - systemtrayicon: only delete the systray backend that was used (1d6f32c9)
  - systemtrayicon, widget: Added deallocate memory (cbb7eeca)
  - title: Change title on initial startup on "Add friend" (47d94045, closes #3100)
  - toxme:
  - Delete extra check (d1b706a4)
  - Fixed potential memory leaks (8f4b6869)
  - Fix possible segfault (11ec3947)
  - Use format strings (fc2a5723)
  - Translation fixes (9565a817)
  - video:
  - uses explicit default screen from QGuiApplication (d2189f38)
  - usage of invalid file descriptors on error (556a8750)
  - incorrect desktop video resolution when using HiDPI (75b40d0a)
  - widget: Change focus after creating group (b111c509)
  - widget, contentdialog: Added reset icon after activate chat window (4edc5996)
  Performance
  - camerasource: Passed parameter by reference (910c41f4)
  - contentdialog: Delete redundant conditions (904a1d49)
  Features
  - install icons with make install on unix (218228b6)
  - disable building with filter_audio by default (116cc936)
  - audio: add (repair) support for group audio calls (356543ca)
  - chatform: add support for non-local file and samba share links (47764c03)
  - profileform: Added ability to change toxme server (41c5d4bf)
  - toxme:
  - Add save toxme info (204fe1d3)
  - Add ToxMe registration (cb8bf134)
* Sat Mar 19 2016 ecsos@opensuse.org
- update to 1.3.0
  - New and improved sound code
  - New HTTPS ToxMe protocol support
  - Translation updates
  - Miscellaneous fixes and polishing
* Sat Jan 23 2016 ecsos@opensuse.org
- update to 1.2.4
  - Fix the updater not finding updates when the working directory
    wasn't the same as the install directory
- changes from 1.2.3
  - Add toxme.io HTTPS lookup support
* Fri Dec 25 2015 ecsos@opensuse.org
- change from git version to version 1.2.2
* Sat Nov 15 2014 ecsos@opensuse.org
- update to newest git version
- correct spec file
* Thu Jul 17 2014 zawertun@gmail.com
- toxgui -> qTox
* Mon Jul  7 2014 zawertun@gmail.com
- Initial version
